@@ -138,11 +138,12 @@ SQL_TYPE_BOOLEAN = 32764
 SQL_TYPE_NULL = 32766
 
 
-ISOLATION_LEVEL_READ_UNCOMMITTED = 0
+ISOLATION_LEVEL_READ_COMMITED_LEGACY = 0
 ISOLATION_LEVEL_READ_COMMITED = 1
 ISOLATION_LEVEL_REPEATABLE_READ = 2
+ISOLATION_LEVEL_SNAPSHOT = ISOLATION_LEVEL_REPEATABLE_READ
 ISOLATION_LEVEL_SERIALIZABLE = 3
-ISOLATION_LEVEL_READ_COMMITED_READ_ONLY = 4
+ISOLATION_LEVEL_READ_COMMITED_RO = 4
 
 # Database Parameter Block parameter
 isc_dpb_version1 = 1
