@@ -20,7 +20,7 @@ from firebirdsql.utils import *
 from firebirdsql.wireprotocol import WireProtocol, INFO_SQL_SELECT_DESCRIBE_VARS
 from firebirdsql.socketstream import SocketStream
 from firebirdsql.xsqlvar import XSQLVAR, calc_blr, parse_select_items, parse_xsqlda
-__version__ = '0.9.1'
+__version__ = '0.9.2'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -58,7 +58,7 @@ def TimeFromTicks(ticks):
 def TimestampFromTicks(ticks):
     return apply(Timestamp,time.localtime(ticks)[:6])
 def Binary(b):
-    return bs(b)
+    return bytes(b)
 
 class DBAPITypeObject:
     def __init__(self,*values):
@@ -209,7 +209,7 @@ def _fetch_generator(stmt):
                             r[i] = connection.bytes_to_ustr(r[i])
                         else:
                             r[i] = connection.bytes_to_str(r[i])
-            yield r
+            yield tuple(r)
     DEBUG_OUTPUT("_fetch_generator() StopIteration()")
     raise StopIteration()
 
